#!/bin/sh
#
# Post install script for IMNSearch indexes
#       1) Registers the index with the search engine if possible
#       2) Adds an entry for the index in the lookup table
#
# script debug flag
# set -x
#
##############################################################################
#        INDEX specific section
##############################################################################
#
# Put in index type (SBCS/DBCS)
# NOTE: NO MIXTURE OF INDEX TYPES
# all indexes that get installed in one installation option have
# to have the same type, either SBCS or DBCS
#
index_type=$1
#
#
# Put in names of index directories being used during installation
# e.g if your index installed in /usr/docsearch/AIX4cmds/data etc
# use AIXcmds as you indexdir_name_1
# ATTENTION: the name is use case sensitive
# The index name is being generated from the directory name by
# uppercasing
indexdir_name_1="$2"
#
# Put in titles of indexes being installed (EX: "AIX commands")
index_title_1="$2"
#
# Put in locations of the documents belonging to the indexes
# (EX: "/usr/share/man/info/bos/cmds")
document_loc_1="http://localhost:49213/cgi-bin/abtwebx.exe/${3}/q/Extract/${4}/${5}/"
#
##############################################################################
#        End of INDEX specfic section
##############################################################################
#
##############################################################################
#
# !!! DON'T CHANGE ANYTHING FROM HERE DOWN !!!
##############################################################################
dummy()
{
return
}
system=`uname`
case "$system" in
        "AIX")  ECHO=echo
                netq_install_dir="/usr/IMNSearch"
                ;;
        "HP-UX")ECHO=dummy
                netq_install_dir="/opt/IMNSearch"
                if [ "$LANG" = "" ]
                then
                  LANG=C
                  export LANG
                fi
                if [ "$NLSPATH" = "" ]
                then
                   NLSPATH="/usr/lib/nls/%L/%N:/usr/lib/nls/msg/%L/%N"
                   export NLSPATH
                fi
                ;;
        "SunOS")ECHO=dummy
                netq_install_dir="/opt/IMNSearch"
                if [ "$LANG" = "" ]
                then
                    LANG=C
                    export LANG
                fi
                if [ "$NLSPATH" = "" ]
                then
                  NLSPATH="/usr/lib/locale/%L/LC_MESSAGES/%N"
                  export NLSPATH
                fi
                ;;
        *)      echo "Operating system not supported."
                exit 1
                ;;
esac
umask 022
# directory where indexes are search by the engine
src_index_dir="/usr/docsearch/indexes"
# directory for writeable file of the index
trg_index_dir="/var/docsearch/indexes"
# lookup table file for all indexes
map_file="imnmap.dat"
#
# define system specific commands with full path
sys_ls="/usr/bin/ls"
sys_cp="/usr/bin/cp"
sys_rm="/usr/bin/rm"
sys_mkdir="/usr/bin/mkdir"
sys_chmod="/usr/bin/chmod"
sys_chown="/usr/bin/chown"
sys_grep="/usr/bin/grep"
# command to update the master table file
update_mt_sbcs="$netq_install_dir/cli/imnmtupd /etc/IMNSearch/data"
update_mt_dbcs="$netq_install_dir/cli/imqmtupd -m /etc/IMNSearch/dbcshelp"
#
# dependend on the index type, switch commands an environment
if [ $index_type = "SBCS" ]
then
  instance_name=imnhelp
  start_exe=/usr/bin/imnss
else
  if [ $index_type = "DBCS" ]
  then
    # set the correct environment
    if [ -x $netq_install_dir/bin/imq_env ]
    then
      . $netq_install_dir/bin/imq_env
    fi
    instance_name=dbcshelp
    start_exe=/usr/bin/imqss
  else
    $ECHO "Either none or a wrong index_type has been specified ..."
    exit 1
  fi
fi

##########################
# initialize installation
##########################
# if search service is installed, stop it

if [ -x $start_exe ]
then
    # Stop the Search engine
    $start_exe -stop $instance_name

fi

# check if there is an existing configuration and save it

if [ -f $src_index_dir/$map_file ]
then
   # save the config file before doing any work
   $sys_cp $src_index_dir/$map_file $src_index_dir/$map_file.save
   if [ $? -ne 0 ]
   then
        $sys_rm -f $src_index_dir/$map_file.save
        $ECHO "Could not create $src_index_dir/$map_file.save !"
        $ECHO "Exiting...."
        exit 1
   fi
fi

# register every index in the lookup table and if search service
# is installed also with the search service
#
# arrays start with offset 1     DO NOT CHANGE
count=1
status=0


while [ ! -z "`eval echo \\$indexdir_name_$count`" ]
do
  indexdir_name="`eval echo \\$indexdir_name_$count`"
  indexname=`echo $indexdir_name | tr "[:lower:]" "[:upper:]"`
  document_loc="`eval echo \\$document_loc_$count`"
  index_title="`eval echo \\$index_title_$count`"

  #increase the count
  count=`expr ${count} + 1`

  # Add an entry in the lookup table for the index
  if [ -f $src_index_dir/$map_file ]
  then
        found=`$sys_grep '^"'$indexname'"' $src_index_dir/$map_file`
        if [ ! -z "$found" ]
        then
             $ECHO "Index \"$indexname\" already exists in the lookup table."
             $sys_rm -f $src_index_dir/$map_file.save
             status=1 ; continue
        fi
        # if regular entry: use "\n" as separator in dataline
        echo "\n\"$indexname\",\"$document_loc\",\"$index_title\"\c" >> $src_index_dir/$map_file
  else
        # if first entry: DO NOT USE "\n" as separator in dataline
        echo "\"$indexname\",\"$document_loc\",\"$index_title\"\c" >> $src_index_dir/$map_file
  fi


  if [ $? -ne 0 ]
  then
     $ECHO "Error creating entry in lookup table !"
     $ECHO "Exiting ..."
     status=1 ; continue
  fi

  # Register the index with the search engine
  #       Will do nothing if IMNSearch is not installed
  #
  if [ -x $start_exe ]
  then
        # create directory under /var/docsearch/indexes

        $sys_mkdir -p $trg_index_dir/$indexdir_name/data
        if [ $? -ne 0 ]
        then
          $ECHO "Error creating index directory !"
          $ECHO "Exiting ..."
          status=1 ; continue
        fi
        $sys_mkdir -p $trg_index_dir/$indexdir_name/work
        if [ $? -ne 0 ]
        then
          $ECHO "Error creating index directory !"
          $ECHO "Exiting ..."
          status=1 ; continue
        fi

        # copy neccessary files
        $sys_cp $src_index_dir/$indexdir_name/admtb/im*.dat $trg_index_dir/$indexdir_name/data
        if [ $? -ne 0 ]
        then
          $ECHO "Error copying index files to directory !"
          $ECHO "Exiting ..."
          status=1 ; continue
        fi

        $sys_cp /etc/IMNSearch/imnkeep.it $trg_index_dir/$indexdir_name/work
        if [ $? -ne 0 ]
        then
          $ECHO "Error copying index files to directory !"
          $ECHO "Exiting ..."
          status=1 ; continue
        fi
        # change the ownership of the index directories
        $sys_chown -R imnadm:imnadm $trg_index_dir/$indexdir_name
        if [ $? -ne 0 ]
        then
          $ECHO "Error changing ownership of index directories !"
          $ECHO "Exiting ..."
          status=1 ; continue
        fi

        # change the permissions of the index files
        $sys_chmod -R 640 $trg_index_dir/$indexdir_name/data/im*.dat
        if [ $? -ne 0 ]
        then
          $ECHO "Error changing permission of index files !"
          $ECHO "Exiting ..."
          status=1 ; continue
        fi

        # Register the index with the search engine
        if [ $index_type = "SBCS" ]
        then
           $update_mt_sbcs  $indexname $src_index_dir/$indexdir_name/data \
$src_index_dir/$indexdir_name/work
        else
           $update_mt_dbcs  -n $indexname -i $src_index_dir/$indexdir_name/data \
-w $src_index_dir/$indexdir_name/work
        fi
  fi
done

if [ $status -ne 0 ]; then
     $ECHO "Error in updating index lookup table !"
     $ECHO "Exiting ..."
     exit 1
fi


if [ -d $trg_index_dir ]
then
  $sys_cp $src_index_dir/$map_file $trg_index_dir/$map_file
  if [ $? -ne 0 ]
  then
      $ECHO "Could not copy $src_index_dir/$map_file !"
      $ECHO "Exiting...."
      exit 1
  fi
  if [ -x $start_exe ]
  then
    $sys_chown imnadm:imnadm $trg_index_dir/$map_file

    if [ $? -ne 0 ]
    then
        $ECHO "Error changing permissions on file $trg_index_dir/$map_file!"
        $ECHO "Exiting...."
        exit 1
    fi
  fi
fi

#Every thing is ok, now delete save file
if [ -f $src_index_dir/$map_file.save ]
then
   $sys_rm -f $src_index_dir/$map_file.save
   $sys_rm -f $trg_index_dir/$map_file.save
fi

# if search service is installed, start it again

if [ -x $start_exe ]
then
    # Start the Search engine
    $start_exe -start $instance_name

fi
exit 0
